@@ -5,20 +5,31 @@ from .provider import Alchemy
 NETWORKS = {
     "ethereum": [
         "mainnet",
-        "goerli",
         "sepolia",
     ],
     "arbitrum": [
         "mainnet",
-        "goerli",
+        "sepolia",
+    ],
+    "base": [
+        "mainnet",
+        "sepolia",
+    ],
+    "fantom": [
+        "opera",
+        "testnet",
     ],
     "optimism": [
         "mainnet",
-        "goerli",
+        "sepolia",
     ],
     "polygon": [
         "mainnet",
-        "mumbai",
+        "amoy",
+    ],
+    "polygon-zkevm": [
+        "mainnet",
+        "cardona",
     ],
 }
 
