@@ -13,7 +13,7 @@ FEATURE_NOT_AVAILABLE_BECAUSE_OF_TIER_RESPONSE = (
     "https://docs.alchemy.com/alchemy/documentation/apis"
 )
 FEATURE_NOT_AVAILABLE_BECAUSE_OF_NETWORK_RESPONSE = (
-    "trace_transaction is not available on the ETH_GOERLI. "
+    "trace_transaction is not available on the ETH_SEPOLIA. "
     "For more information see our docs: "
     "https://docs.alchemy.com/alchemy/documentation/apis/ethereum"
 )
@@ -30,13 +30,14 @@ def networks():
 
 
 @pytest.fixture
-def missing_token(mocker):
+def missing_token(alchemy_provider, mocker):
     env = os.environ.copy()
     mock = mocker.patch("os.environ.get")
 
     def side_effect(key, *args, **kwargs):
         return None if "WEB3" in key else env.get(key, *args, **kwargs)
 
+    alchemy_provider.network_uris = {}
     mock.side_effect = side_effect
     return mock
 
@@ -91,4 +92,4 @@ def feature_not_available_http_error(mocker, request):
 
 @pytest.fixture
 def alchemy_provider(networks) -> Alchemy:
-    return networks.ethereum.goerli.get_provider("alchemy")
+    return networks.ethereum.sepolia.get_provider("alchemy")
